CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
38 lines
1.4 KiB
Plaintext
38 lines
1.4 KiB
Plaintext
// Copyright (c) 2026 Advanced Micro Devices, Inc.
|
|
// All rights reserved.
|
|
|
|
#include <hip/hip_runtime.h>
|
|
|
|
/// Tiled matrix multiplication kernel for multi-workgroup stress testing.
|
|
///
|
|
/// Each workgroup computes 64 contiguous elements of the output matrix C = A * B.
|
|
/// The global thread ID determines which element each lane computes:
|
|
/// global_id = workgroup_id * 64 + thread_id
|
|
/// row = global_id / N, col = global_id % N
|
|
///
|
|
/// With N=128 and 256 workgroups of 64 threads each, all 16384 output elements
|
|
/// are covered, distributing one workgroup per compute unit across 256 CUs.
|
|
///
|
|
/// Kernel arguments (passed via the argument buffer):
|
|
/// A - pointer to input matrix A (N*N floats, row-major)
|
|
/// B - pointer to input matrix B (N*N floats, row-major)
|
|
/// C - pointer to output matrix C (N*N floats, row-major)
|
|
/// N - matrix dimension
|
|
|
|
extern "C" __global__ void matmul_tiled(const float *__restrict__ A,
|
|
const float *__restrict__ B,
|
|
float *__restrict__ C, unsigned N) {
|
|
// blockDim.x is always 64 (one wavefront per workgroup).
|
|
constexpr unsigned BLOCK_SIZE = 64;
|
|
unsigned gid = blockIdx.x * BLOCK_SIZE + threadIdx.x;
|
|
|
|
if (gid < N * N) {
|
|
unsigned row = gid / N;
|
|
unsigned col = gid % N;
|
|
float sum = 0.0f;
|
|
for (unsigned k = 0; k < N; ++k)
|
|
sum += A[row * N + k] * B[k * N + col];
|
|
C[row * N + col] = sum;
|
|
}
|
|
}
|